@@ -1,6 +1,21 @@
 # test.prolog.R
 
-printf <- function(fmt, ...) cat(sprintf(fmt, ...), sep="")
+# A safe version of sprintf.
+# Like sprintf except that %s on NULL prints "NULL" rather than
+# preventing the entire string from being printed
+#
+# e.g. sprintf("abc %s def", NULL) returns an empty string -- a silent failure!
+# but   sprint("abc %s def", NULL) returns "abc NULL def"
+#
+# e.g. sprintf("abc %d def", NULL) returns an empty string!
+# but   sprint("abc %d def", NULL) causes an error msg (not a silent failure)
+sprint <- function(fmt, ...)
+{
+    dots <- list(...)
+    dots <- lapply(dots, function(e) if(is.null(e)) "NULL" else e)
+    do.call(sprintf, c(fmt, dots))
+}
+printf <- function(fmt, ...) cat(sprint(fmt, ...), sep="")
 cat0 <- function(...) cat(..., sep="")
 strip.space <- function(s) gsub("[ \t\n]", "", s)
 # test that we got an error as expected from a try() call
@@ -12,7 +27,7 @@ expect.err <- function(object, expected.msg="")
             cat0("Got error as expected from ",
                  deparse(substitute(object)), "\n")
         else
-            stop(sprintf("Expected: %s\n  Got:      %s",
+            stop(sprint("Expected: %s\n  Got:      %s",
                          expected.msg, substr(msg[1], 1, 1000)))
     } else
         stop("Did not get expected error: ", expected.msg)
